summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--packages/frontend/src/components/SkUrlPreviewGroup.vue8
1 files changed, 6 insertions, 2 deletions
diff --git a/packages/frontend/src/components/SkUrlPreviewGroup.vue b/packages/frontend/src/components/SkUrlPreviewGroup.vue
index 4c43c989bd..beba20f783 100644
--- a/packages/frontend/src/components/SkUrlPreviewGroup.vue
+++ b/packages/frontend/src/components/SkUrlPreviewGroup.vue
@@ -207,9 +207,13 @@ function deduplicatePreviews(previews: Summary[]): Summary[] {
// Skip if we have AP and the other doesn't
if (preview.activityPub && !p.activityPub) return false;
+ // Skip if we have a note and the other doesn't
+ if (preview.note && !p.note) return false;
+
// Skip later previews (keep the earliest instance)...
- // ...but only if we have AP or the later one doesn't.
- if (i > index && (preview.activityPub || !p.activityPub)) return false;
+ // ...but only if we have AP or the later one doesn't...
+ // ...and only if we have note or the later one doesn't.
+ if (i > index && (preview.activityPub || !p.activityPub) && (preview.note || !p.note)) return false;
// If we get here, then "preview" is a duplicate of "p" and should be skipped.
return true;